/*global define,window*/
define([
    'testsuite/qunit',
    'jquery',
    'ep',
    'testsuite/qunit-fixture!de_epages/ipayment/ui/ipaymentcapture-test',
    'de_epages/ipayment/ui/ipaymentcapture'
], function(QUnit, $, ep, fixture, ipaymentcapture) {

    'use strict';
    QUnit.module('de_epages/ipayment/ui/ipaymentcapture', {
        setup: fixture.init,
        teardown: fixture.destroy
    });
//
    QUnit.test('Check if the behaviour of capture link is as expected for transaction status = STATUS_ACCEPTED ', 1, function() {

        var UIControlParameters = {
                Objectid: "12345",
    		    PaymentTypeAlias: "Ipayment",
    		    SelectedTransactionType: "preauth",
    		    TransStatus: "STATUS_ACCEPTED",
    		    DisplayCapture: $('#DisplayCapture'),
    		    CaptureLink: $('#CaptureLink')
        };

        ipaymentcapture( UIControlParameters );

        QUnit.strictEqual(
            $("#CaptureLink").attr('class'),
            'ep-captureamount ep-reloadlocation',
            'Check that the link has the expected classes for a properly execution. We are waiting for the values ep-captureamount ep-reloadlocation in link class attribute'
        );
    });
//
    QUnit.test('Check if the behaviour of capture link is as expected for transaction status = STATUS_FAILED ', 1, function() {

        var UIControlParameters = {
                Objectid: "12345",
    		    PaymentTypeAlias: "Ipayment",
    		    SelectedTransactionType: "preauth",
    		    TransStatus: "STATUS_FAILED",
    		    DisplayCapture: $('#DisplayCapture'),
    		    CaptureLink: $('#CaptureLink')
        };

        ipaymentcapture( UIControlParameters );

        QUnit.strictEqual(
            $("#CaptureLink").attr('class'),
            'ep-captureamount ep-reloadlocation',
            'Check that the link has the expected classes for a properly execution. We are waiting for the values ep-captureamount ep-reloadlocation in link class attribute'
        );
    });
//
    QUnit.test('Check if the behaviour of capture link is as expected for empty transaction status', 1, function() {

        var UIControlParameters = {
                Objectid: "12345",
    		    PaymentTypeAlias: "Ipayment",
    		    SelectedTransactionType: "preauth",
    		    TransStatus: "",
    		    DisplayCapture: $('#DisplayCapture'),
    		    CaptureLink: $('#CaptureLink')
        };

        ipaymentcapture( UIControlParameters );

        QUnit.strictEqual(
            $("#CaptureLink").attr('class'),
            'Disabled',
            'Check that the link has the expected classes to do not be able to use it. We are waiting for the value Disable in link class attribute'
        );
    });
//
    QUnit.test('Check if the behaviour of capture link is as expected for non-ipayment payment methods ', 1, function() {

        var UIControlParameters = {
                Objectid: "12345",
    		    PaymentTypeAlias: "Visa",
    		    SelectedTransactionType: "preauth",
    		    TransStatus: "",
    		    DisplayCapture: $('#DisplayCapture'),
    		    CaptureLink: $('#CaptureLink')
        };

        ipaymentcapture( UIControlParameters );

        QUnit.strictEqual(
            $("#DisplayCapture").is(":visible"),
            false,
            'Check that the div that contains the capture and capture elements are not visible. We are waiting for the attribute visible of the above div at false'
        );
    });
//
    QUnit.test('Check if the behaviour of capture link is as expected if we get an unexpected transaction status', 1, function() {

        ep.ajax = function(o) {
            var result = $.Deferred();

            result.resolve({
                "status": "ok",
                "message": "",
                "transstatus": "STATUS_FAILED",
            });

            return result;
        };

        var UIControlParameters = {
                Objectid: "12345",
    		    PaymentTypeAlias: "Ipayment",
    		    SelectedTransactionType: "preauth",
    		    TransStatus: "STATUS_ACCEPTED",
    		    DisplayCapture: $('#DisplayCapture'),
    		    CaptureLink: $('#CaptureLink')
        };

        ipaymentcapture(UIControlParameters );


        $('#CaptureLink').trigger('click');
        $('#YesId').trigger('click');

        QUnit.strictEqual(
            $("#Response").html(),
            'Transaction Failed',
            'Check that the value of the dialog is the expected for a non expected transstatus. We are waiting for the word "Transaction Failed" at the dialog'
        );

        // destroy dialog instance again
        $('.ui-dialog-content.ui-widget-content').uiDialog('destroy');
    });
//
    QUnit.test('Check if the behaviour of capture link is as expected if it goes well', 2, function() {

        ep.ajax = function(o) {
            var result = $.Deferred();

            result.resolve({
                "status": "ok",
                "message": "",
                "transstatus": "STATUS_PAID",
            });

            return result;
        };

        // Mocking the window to avoid the reload
        this.mockWindow = {
            location: {
                reload: function() {
                    ok(true, "This mock function should be called");
                }
            }
        };

        var UIControlParameters = {
                Objectid: "12345",
    		    PaymentTypeAlias: "Ipayment",
    		    SelectedTransactionType: "preauth",
    		    TransStatus: "STATUS_ACCEPTED",
    		    DisplayCapture: $('#DisplayCapture'),
    		    CaptureLink: $('#CaptureLink'),
    		    CurrentWindow: this.mockWindow
        };

        ipaymentcapture( UIControlParameters );

        $('.ep-captureamount').trigger('click');
        $('#YesId').trigger('click');

        QUnit.strictEqual(
            $("#Response").html(),
            'OK',
            'Check that the value of the dialog is the expected for a properly execution. We are waiting for the word OK at the dialog'
        );

        // destroy dialog instance again
        $('.ui-dialog-content.ui-widget-content').uiDialog('destroy');
    });
//
    QUnit.test('Check if the behaviour of capture link is as expected if it goes wrong', 1, function() {

        ep.ajax = function(o) {
            var result = $.Deferred();

            result.resolve({
                "status": "error",
                "message": "salsitxa"
            });

            return result;
        };

        var UIControlParameters = {
                Objectid: "12345",
    		    PaymentTypeAlias: "Ipayment",
    		    SelectedTransactionType: "preauth",
    		    TransStatus: "STATUS_ACCEPTED",
    		    DisplayCapture: $('#DisplayCapture'),
    		    CaptureLink: $('#CaptureLink'),
        };

        ipaymentcapture( UIControlParameters );

        $('.ep-captureamount').trigger('click');
        $('#YesId').trigger('click');

        QUnit.strictEqual(
            $("#Response").html(),
            'salsitxa',
            'Check that the value of the dialog is the expected for a wrong execution. We are waiting for an error message in the dialog'
        );

        // destroy dialog instance again
        $('.ui-dialog-content.ui-widget-content').uiDialog('destroy');
    });
});